import typer
import json
import praw
import time
from rich.progress import track


app = typer.Typer()

def build_tree(comments):
    tree = []
    for comment in comments:
        # Add the comment to the tree
        
        tree.append({"id": comment.id, "body": comment.body, "replies": []})
        # Recursively build the tree for the replies to this comment
        if comment.replies:
            tree[-1]["replies"] = build_tree(comment.replies)
    return tree

@app.command()
def comment_graph(redditid:str , redditsecret:str , namesubreddit:str , post_category : str ,number_of_post:int ) :
    typer.echo("Please enter your Reddit ID , Reddit Secret , name of subreddit to parse , post-category , number of posts to parse in respective order")
    user_agent = "Scraper 1.0 by /u/MajesticPanic8917"
    reddit = praw.Reddit(
        client_id = redditid ,
        client_secret = redditsecret, 
        user_agent = user_agent
    )
    tree= []
    if number_of_post == 0:
        number_of_post = None

    if post_category == 'rising' :
        submissions = reddit.subreddit(namesubreddit).rising(limit=number_of_post)
    elif post_category == 'hot':
        submissions = reddit.subreddit(namesubreddit).hot(limit=number_of_post)
    elif post_category == 'new':
        submissions = reddit.subreddit(namesubreddit).new(limit=number_of_post)
    elif post_category == 'top':
        submissions = reddit.subreddit(namesubreddit).top(limit=number_of_post)
    else:
        print("ERROR!!!")
        print("Please choose with in hot, new, top, rising")
        return 
    
    try:
        for submission in submissions:
            print(submission.title)
            submission.comments.replace_more(limit=None)
    
            tree_submission = build_tree(submission.comments)
    
            tree.append({"Submission" : submission.title , "comments" : tree_submission})
    except:
        print("ERROR!!!")
        print(f'Please check the details provided REDDIT-ID - {redditid}, REDDIT-SECRET - {redditsecret}, SUBREDDIT-NAME - {namesubreddit}')

    json_data = json.dumps(tree)

    # Save the JSON string to a file
    with open("comments.json", "w") as f:
        f.write(json_data)






# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['reddit_comment_scrapper']

package_data = \
{'': ['*']}

install_requires = \
['praw>=7.6.1,<8.0.0', 'typer[all]>=0.7.0,<0.8.0']

entry_points = \
{'console_scripts': ['reddit_comment_scrapper = '
                     'reddit_comment_scrapper.main:app']}

setup_kwargs = {
    'name': 'reddit-comment-scrapper',
    'version': '0.1.0',
    'description': 'Scrape Reddit Comments as a graph structure',
    'long_description': '# Usage\n\nRun the whl file\n\n## Structure of JSON File\n\n- Each Submission has two entries\n    - Submission Body\n    - List of Dictionary of top level Replies \n- Each reply has 3 enteries\n    - id of reply\n    - Body of Reply\n    - List of Dictionary of second level Replies\n\nAnd this goes on Recursively in a depth first search manner till a reply with no further reply is found\n\nJSON File always stored in a comments.json',
    'author': 'Prarabdha',
    'author_email': 'prabodhkumarsrivastav70@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
